dorianUtils v6.0
This package contains utilities for :
- comUtils : to standardize the dumping of data from different devices(Modbus,Meteo,OPCUA) with a Streamer, SuperDumper_daily and VisualisationMaster_daily
- Simulators : to simulate the flow of data from devices(servers) from comUtils
- utilsD : convenient plotly,pandas extensions to work faster
- versionManagers : to deal with historical data folders and to make them compatible with the daily visualisation master.
